@@ -19,20 +19,20 @@ impl Reimbursements {
      *
      * **Parameters:**
      *
-     * * `start: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `start: Option<uuid::Uuid>` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      */
     pub async fn get_page(
         &self,
-        start: uuid::Uuid,
+        start: Option<uuid::Uuid>,
         page_size: f64,
     ) -> Result<Vec<crate::types::Reimbursement>> {
         let mut query_args: Vec<(String, String)> = Default::default();
         if !page_size.to_string().is_empty() {
             query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        if !start.to_string().is_empty() {
-            query_args.push(("start".to_string(), start.to_string()));
+        if let Some(u) = start {
+            query_args.push(("start".to_string(), u.to_string()));
         }
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!("/reimbursements?{}", query_);
@@ -55,11 +55,7 @@ impl Reimbursements {
         let resp: crate::types::GetReimbursementsResponse = self.client.get(&url, None).await?;
 
         let mut data = resp.data;
-        let mut page = if let Some(p) = resp.page.next {
-            p.to_string()
-        } else {
-            "".to_string()
-        };
+        let mut page = resp.page.next.to_string();
 
         // Paginate if we should.
         while !page.is_empty() {
@@ -74,12 +70,8 @@ impl Reimbursements {
                 Ok(mut resp) => {
                     data.append(&mut resp.data);
 
-                    page = if let Some(p) = resp.page.next {
-                        if p.to_string() != page {
-                            p.to_string()
-                        } else {
-                            "".to_string()
-                        }
+                    page = if resp.page.next != page {
+                        resp.page.next.to_string()
                     } else {
                         "".to_string()
                     };
